@@ -18,6 +18,7 @@ else:
         return p.getPid()
     def is_alive(p):
         return p.isAlive()
+    enable_groups = processing.freezeSupport
     processing.enableLogging(level=logging.INFO)
     get_logger = processing.getLogger
     current_process = processing.currentProcess
@@ -36,6 +37,7 @@ else:
         return p.pid
     def is_alive(p):
         return p.is_alive()
+    enable_groups = processing.freeze_support
     get_logger = processing.get_logger
     current_process = processing.current_process
 
