@@ -57,6 +57,9 @@ class GroupFailed(Exception):
 class WrongMessageTypeSpecified(Exception):
     pass
 
+class ConcreteMessageAlreadyDefined(Exception):
+    pass
+
 def get_logger():
     return processing.get_logger()
     
@@ -97,12 +100,9 @@ class ActorManager(messaging.MessageManager):
         self.objectNameMap = {}
         
         self.gid = 0
-        if transport.RAKNET_AVAILABLE:
-            self.transport = transport.RakNetTransport()
-        else:
-            self.transport = transport.Transport()
-        self.clients = {}
+        self.transport = None
         self.packet_types = {}
+        self.message_map = {}
         # using either Domain Socket (Unix) or Named Pipe (windows) as means
         # for IPC
         self.groups = {}
@@ -127,21 +127,47 @@ class ActorManager(messaging.MessageManager):
         - `True`: if event was consumed
         - `False`: otherwise
         '''
+        # if we are sending adhoc messages, we'll create a message instance with the adhoc type
+        if type(msg) == type(''):
+            # adhoc messages are only allowed if a concrete message class is not constructed
+            if self.message_map.has_key(msg):
+                raise ConcreteMessageAlreadyDefined('A concrete message class of the name "%s" is already defined.  Adhoc messages of this type are not allowed.' % msg)
+            msg = Message(message_type = msg)
         obj = self.objectIDMap[id]
         for recr in self.message_receiver_map[messaging.WildCardMessageType]:
             recr.handle_message(msg)
         return obj.handle_message(msg)
     def queue_message_to_actor(self, id, msg):
+        '''
+        queues message designated for a specific actor
+
+        :Parameters:
+            - `id`: the "id" of the actor
+            - `msg`: the message to be queued
+        '''
         msg.receiverID = id
         self.queue_message(msg)
         return True
     def register_actor(self, obj, name=None):
+        '''
+        register the actor with the actor manager so that the actor can receive messages as well as having "update" called
+        
+        :Parameters:
+            - `obj`: the actor to be registered
+            - `name`: optional.  The name of the actor for which you can refer back to the actor later
+        '''
         messaging.MessageManager.register_receiver(self, obj)
         self.objectIDMap[obj.gid] = obj
         if name:
             self.objectNameMap[name] = obj
         return obj
     def unregister_actor(self, obj):
+        '''
+        unregister the actor from the actor manager.  actor will no longer receive messages or have its "update" method called
+        
+        :Parameters:
+            - `obj`: the actor being unregistered
+        '''
         messaging.MessageManager.unregister_receiver(self, obj)
         del self.objectIDMap[obj.gid]
         
@@ -199,11 +225,13 @@ class ActorManager(messaging.MessageManager):
                 break
         
         # always poll at least one network message here
-        has_more = True
-        while has_more:
-            has_more = self.transport.poll(self.packet_handler)
-            if cut_off_time and util.get_time() > cut_off_time:
-                break
+        if self.transport:
+            has_more = True
+            while has_more:
+                has_more = self.transport.poll(self.packet_handler)
+                if cut_off_time and util.get_time() > cut_off_time:
+                    break
+
         processing.get_logger().debug('process "%s" queue length: %s' % (processing.get_pid(processing.current_process()), self.queue_length))
         
         # process all messages first
@@ -225,23 +253,47 @@ class ActorManager(messaging.MessageManager):
         self.ipc_transport.connect(server_addr)
         self._should_quit = _should_quit
         self.groups[self.PYSAGE_MAIN_GROUP] = (None,server_addr,None)
-    def listen(self, port):
+    def listen(self, host, port, transport_class=transport.SelectUDPTransport):
+        '''
+        starts listening for network messages given the port and the transport class
+
+        :Parameters:
+            - `host`: the host for which the server will bind to
+            - `port`: the port for which the server will listen on
+            ` `transport_class`: optional.  the transport class that will be used to define the protocol
+        '''
         def connection_handler(client_address):
             processing.get_logger().debug('connected to client: %s' % client_address)
-        self.transport.listen(port, connection_handler)
+        self.transport = transport_class()
+        self.transport.listen(host, port, connection_handler)
         return self
-    def connect(self, host, port):
+    def connect(self, host, port, transport_class=transport.SelectUDPTransport):
+        '''
+        connects to a server so that message communication can be started
+
+        :Parameters:
+            - `host`: the host for which to connect to
+            - `port`: the port for which to connect to
+        '''
+        self.transport = transport_class()
         self.transport.connect(host, port)
         return self
-    def send_message(self, msg, clientid):
-        self.transport.send(msg.to_string(), id=self.clients[clientid])
+    def send_message(self, msg, address):
+        '''
+        send a message to a network
+        
+        :Parameters:
+            - `msg`: the message to send
+            - `clientid`: the network for which to send the message to
+        '''
+        self.transport.send(msg.to_string(), address=address)
         return self
     def queue_message_to_group(self, group, msg):
         '''message is serialized and sent to the group (process) specified'''
         if not self.groups.has_key(group):
             raise GroupDoesNotExist('Group "%s" does not exist' % group)
         p, _clientid, switch = self.groups[group]
-        processing.get_logger().info('queuing message "%s" to "%s"' % (msg, self.ipc_transport.peers[_clientid].fileno()))
+        processing.get_logger().info('queuing message "%s" to "%s"' % (msg, _clientid))
         self.ipc_transport.send(msg.to_string(), _clientid)
     def broadcast_message(self, msg):
         self.transport.send(msg.to_string(), broadcast=True)
@@ -266,6 +318,7 @@ class ActorManager(messaging.MessageManager):
         if self.packet_types.has_key(packet_class.packet_type):
             raise PacketTypeError('Packet_type is already registered with packet "%s"' % self.packet_types[packet_class.packet_type])
         self.packet_types[packet_class.packet_type] = packet_class
+        self.message_map[packet_class.__name__] = packet_class
     def add_process_group(self, name, default_actor_class=None, max_tick_time=None, interval=.03):
         '''adds a process group to the pool'''
         if self.is_main_process == None:
@@ -315,7 +368,6 @@ class ActorManager(messaging.MessageManager):
             self.transport = transport.RakNetTransport()
         else:
             self.transport = transport.Transport()
-        self.clients = {}
         # not removing the auto-registered packet types
         # self.packet_types = {}
         self.groups = {}
